From 624793eac882fcd4daf7055cf1aef4058e2dd4f7 Mon Sep 17 00:00:00 2001
From: Frederic Cambus <fred@statdns.com>
Date: Sun, 3 Jul 2022 19:54:58 +0200
Subject: [PATCH] Added support for building with Clang on OpenBSD. (#10028)

---
 makefile              | 17 +++++++++++++++++
 scripts/toolchain.lua |  5 +++++
 2 files changed, 22 insertions(+)

diff --git a/makefile b/makefile
index 2cbc41354190..891c91954894 100644
--- a/makefile
+++ b/makefile
@@ -1490,6 +1490,23 @@ openbsd_x86: generate $(PROJECTDIR)/$(MAKETYPE)-openbsd/Makefile
 	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd config=$(CONFIG)32 precompile
 	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd config=$(CONFIG)32
 
+#-------------------------------------------------
+# gmake-openbsd-clang
+#-------------------------------------------------
+
+$(PROJECTDIR)/$(MAKETYPE)-openbsd-clang/Makefile: makefile $(SCRIPTS) $(GENIE)
+	$(SILENT) $(GENIE) $(PARAMS) $(TARGET_PARAMS) --gcc=openbsd-clang --gcc_version=$(CLANG_VERSION) $(MAKETYPE)
+
+.PHONY: openbsd_x64_clang
+openbsd_x64_clang: generate $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang/Makefile
+	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang config=$(CONFIG)64 precompile
+	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang config=$(CONFIG)64
+
+.PHONY: openbsd_x86_clang
+openbsd_x86_clang: generate $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang/Makefile
+	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang config=$(CONFIG)32 precompile
+	$(SILENT) $(MAKE) -C $(PROJECTDIR)/$(MAKETYPE)-openbsd-clang config=$(CONFIG)32
+
 #-------------------------------------------------
 # Clean/bootstrap
 #-------------------------------------------------
diff --git a/scripts/toolchain.lua b/scripts/toolchain.lua
index 4a3eac025462..c8b90f3d738c 100644
--- a/scripts/toolchain.lua
+++ b/scripts/toolchain.lua
@@ -30,6 +30,7 @@ newoption {
 		{ "netbsd",        "NetBSD"                },
 		{ "netbsd-clang",  "NetBSD (clang compiler)"},
 		{ "openbsd",       "OpenBSD"                },
+		{ "openbsd-clang", "OpenBSD (clang compiler)"},
 		{ "osx",           "OSX (GCC compiler)"     },
 		{ "osx-clang",     "OSX (Clang compiler)"   },
 		{ "solaris",       "Solaris"                },
@@ -136,6 +137,10 @@ function toolchain(_buildDir, _subDir)
 			location (_buildDir .. "projects/" .. _subDir .. "/".. _ACTION .. "-openbsd")
 		end
 
+		if "openbsd-clang" == _OPTIONS["gcc"] then
+			location (_buildDir .. "projects/" .. _subDir .. "/".. _ACTION .. "-openbsd-clang")
+		end
+
 		if "linux-gcc" == _OPTIONS["gcc"] then
 			-- Force gcc-4.2 on ubuntu-intrepid
 			if _OPTIONS["distro"]=="ubuntu-intrepid" then
